/* Theme Description
-------------------------------------------------

	  Theme Name:
	  Author:
	  Support:
	  Description:
	  Version:
	  
------------------------------------------------- 
*/

/* CSS Index
-------------------------------------------------

	1. Theme default css
	2. header
	3. slider
	4. about-area
	5. features-box
	6. department
	7. team
	8. video-area
	9. counter
	10. footer

-------------------------------------------------
*/

// Defult
@import 'variables';
@import 'mixins';
@import 'overlay';
@import 'common';
@import 'color';


// Deful Element Page
@import 'blog_page';
@import 'blog';
@import 'contact';
@import 'bradcam';
@import 'extend';
@import 'elements';


// Homepage1
@import 'headerMenu';
@import 'h1-hero';
@import 'team';
@import 'services_section';
@import 'favourite-place';
@import 'video-area';
@import 'support-company';
@import 'testimonial';
@import 'pagination';
@import 'footer';

// inner Page
@import 'services';



