$font-primary: 'Poppins',Arial, sans-serif;

// Overrides
$grid-gutter-width: 40px !default; 
$border-radius-base:  4px !default;
$padding-base-vertical: 14px !default;

$brand-primary: #F7B633 !default;
$brand-yellow: #F7AF1D !default;
$brand-footer-color: #1E2022;

$brand-white: #fff;
$brand-black: #000;
$brand-darker: #444;
$brand-gray: #ccc;
$brand-lighter: #e9e9e9;
$brand-body-color: #e8e8e8;
$brand-selection-color: #f9f6f0;
$brand-overlay-color: #4c4a8a;
$brand-bg-color: $brand-white;

$input-border-focus:  $brand-primary !default;
$form-group-margin-bottom: 30px !default;



// Mixin
@mixin translateX($translatex) {
	-moz-transform: translateX($translatex);
	-webkit-transform: translateX($translatex);
	-ms-transform: translateX($translatex);
	-o-transform: translateX($translatex);
	transform: translateX($translatex);
}
@mixin transition($transition) {
    -moz-transition:    all $transition ease;
    -o-transition:      all $transition ease;
    -webkit-transition: all $transition ease;
    -ms-transition: 		all $transition ease;
    transition:         all $transition ease;
}
@mixin inline-block() {
	display:-moz-inline-stack;
	display:inline-block;
	zoom:1;
	*display:inline;
}

@mixin border-radius($radius) {
  -webkit-border-radius: $radius;
     -moz-border-radius: $radius;
      -ms-border-radius: $radius;
          border-radius: $radius;
}
@mixin flex() {
	display: -webkit-box;      
  	display: -moz-box;         
  	display: -ms-flexbox;      
  	display: -webkit-flex;     
  	display: flex;             
}
@mixin flexwrap() {
	flex-wrap: wrap;
	-webkit-flex-wrap: wrap; 
	-moz-flex-wrap: wrap; 
}

@font-face {
	font-family: 'icomoon';
	src:url('../fonts/icomoon/icomoon.eot?srf3rx');
	src:url('../fonts/icomoon/icomoon.eot?srf3rx#iefix') format('embedded-opentype'),
		url('../fonts/icomoon/icomoon.ttf?srf3rx') format('truetype'),
		url('../fonts/icomoon/icomoon.woff?srf3rx') format('woff'),
		url('../fonts/icomoon/icomoon.svg?srf3rx#icomoon') format('svg');
	font-weight: normal;
	font-style: normal;
}

@mixin icomoon() {
	font-family: 'icomoon';
	speak: none;
	font-style: normal;
	font-weight: normal;
	font-variant: normal;
	text-transform: none;
	line-height: 1;

	/* Better Font Rendering =========== */
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
	
}

@mixin gradient-background(){
	background: #00b7ea; /* Old browsers */
	background: -moz-linear-gradient(45deg, #43DDE6 0%, #9870FC 100%); /* FF3.6-15 */
	background: -webkit-linear-gradient(45deg, #43DDE6 0%,#9870FC 100%); /* Chrome10-25,Safari5.1-6 */
	background: linear-gradient(45deg, #43DDE6 0%,#9870FC 100%); /* W3C, IE10+, FF16+, Chrome26+, Opera12+, Safari7+ */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#43DDE6', endColorstr='#9870FC',GradientType=1 ); /* IE6-9 fallback on horizontal gradient */
}

// Import 
@import 'bootstrap/mixins';
@import 'bootstrap/variables';




/* =======================================================
*
* 	Template Style 
*
* ======================================================= */

body {
	font-family: $font-primary;
	font-weight: 300;
	font-size: 15px;
	line-height: 1.7;
	color: lighten($brand-black,50%);
	background: lighten($brand-black,96%);
}
#page {
	position: relative;
	overflow-x: hidden;
	width: 100%;
	height: 100%;
	@include transition(.5s);
	.offcanvas & {
		overflow: hidden;	
		position: absolute;
		
		&:after {
			@include transition(2s);
			position: absolute;
			top: 0;
			right: 0;
			bottom: 0;
			left: 0;
			z-index: 101;
			background: rgba(0,0,0,.7);
			content: "";
		}
	}
}
a {
	color: $brand-primary;
	@include transition(.5s);
	&:hover, &:active, &:focus {
		color: $brand-primary;
		outline: none;
		text-decoration: none;
	}
}
p {
	margin-bottom: 20px;
}

h1, h2, h3, h4, h5, h6, figure {
	color: $brand-black;
	font-family: $font-primary;
	font-weight: 400;
	margin: 0 0 20px 0;
}
::-webkit-selection {
  color: $brand-white;
  background: $brand-primary;
}

::-moz-selection {
  color: $brand-white;
  background: $brand-primary;
}
::selection {
  color: $brand-white;
  background: $brand-primary;
}

.colorlib-nav {
	margin: 0;
	position: absolute;
	top: 0;
	left: 0;
	right: 0;	
	z-index: 9;
	margin: 0 auto;
	@media screen and (max-width: $screen-sm ) {
		margin: 0;
	}
	.top-menu{
		padding: 40px 30px;
		@media screen and (max-width: $screen-sm ) {
			padding: 28px 1em;
		}

	}
	#colorlib-logo {
		font-size: 24px;
		margin: 0;
		padding: 0;
		text-transform: uppercase;
		font-weight: 700;
		a{
			position: relative;
			color: $brand-white;
		}
	}
	.menu-1 {
		@media screen and (max-width: $screen-sm ) {
			display: none;
		}
	}
	ul {
		padding: 0;
		margin: 8px 0 0 0;
		li {
			padding: 0;
			margin: 0;
			list-style: none;
			display: inline;
			font-weight: 400;
			a {
				position: relative;
				font-size: 15px;
				padding: 30px 12px;
				color: rgba(255,255,255,.7);
				@include transition(.5s);

				&:hover{
					color: $brand-primary;
				}
			}
			&.has-dropdown {
				position: relative;
				.dropdown {
					width: 140px;
					-webkit-box-shadow: 0px 14px 33px -9px rgba(0,0,0,0.75);
					-moz-box-shadow: 0px 14px 33px -9px rgba(0,0,0,0.75);
					box-shadow: 0px 14px 33px -9px rgba(0,0,0,0.75);
					z-index: 1002;
					visibility: hidden;
					opacity: 0;
					position: absolute;
					top: 40px;
					left: 0;
					text-align: left;
					background: $brand-black;
					padding: 20px;
					@include border-radius(4px);
					@include transition(.0s);
					&:before {
						bottom: 100%;
						left: 40px;
						border: solid transparent;
						content: " ";
						height: 0;
						width: 0;
						position: absolute;
						pointer-events: none;
						border-bottom-color: #000;
						border-width: 8px;
						margin-left: -8px;
					}
					
					li {
						display: block;
						margin-bottom: 7px;
						&:last-child {
							margin-bottom: 0;
						}
						a {
							padding: 2px 0;
							display: block;
							color: lighten($brand-black, 60%);
							line-height: 1.2;
							text-transform: none;
							font-size: 13px;
							letter-spacing: 0;
							&:hover {
								color: $brand-white;
							}
						}
					}
				}
				&:hover, &:focus {
					a {
						color: $brand-primary;
					}
				}
			}
			&.btn-cta {
				a {
					padding: 30px 0px !important;
					color: $brand-white;
					span {
						background: rgba($brand-primary,1);
						padding: 4px 10px;
						@include inline-block;
						@include transition(.3s);
						@include border-radius(100px);
					}
					&:hover {
						span {
							-webkit-box-shadow: 0px 14px 20px -9px rgba(0,0,0,0.75);
							-moz-box-shadow: 0px 14px 20px -9px rgba(0,0,0,0.75);
							box-shadow: 0px 14px 20px -9px rgba(0,0,0,0.75);
						}
					}
				}
			}
			&.active {
				> a {
					color: $brand-primary!important;
					position: relative;

					&:after{
						opacity: 1;
						-webkit-transform: translate3d(0, 0, 0);
						transform: translate3d(0, 0, 0);
					}
				}
			}
		}
	}
}

#colorlib-counter,
.colorlib-bg{
	background-size: cover;
	background-position: top center;
	background-repeat: no-repeat;
	position: relative;
}

.colorlib-video {
	overflow: hidden;
	@media screen and (max-width: $screen-md){
		height: 450px;
	}
	a {
		z-index: 1001;
		position: absolute;
		top: 50%;
		left: 50%;
		margin-top: -45px;
		margin-left: -45px;
		width: 90px;
		height: 90px;
		display: table;
		text-align: center;
		background: $brand-white;
		
		-webkit-box-shadow: 0px 14px 30px -15px rgba(0,0,0,0.75);
		-moz-box-shadow: 0px 14px 30px -15px rgba(0,0,0,0.75);
		-ms-box-shadow: 0px 14px 30px -15px rgba(0,0,0,0.75);
		-o-box-shadow: 0px 14px 30px -15px rgba(0,0,0,0.75);
		box-shadow: 0px 14px 30px -15px rgba(0,0,0,0.75);
		@include border-radius(50%);
		
		i {
			text-align: center;
			display: table-cell;
			vertical-align: middle;
			font-size: 40px;
			color: $brand-primary;

		}
	}
	.overlay {
		position: absolute;
		top: 0;
		left: 0;
		right: 0;
		bottom: 0;
		background: rgba(0, 0, 0, .3);
		@include transition(.5s);
	}
	&:hover {
		.overlay {
			background: rgba(0, 0, 0, .7);		
		}
		a {
			-webkit-transform: scale(1.1);
			-moz-transform: scale(1.1);
			-ms-transform: scale(1.1);
			-o-transform: scale(1.1);
			transform: scale(1.1);
			
		}
	}
}

#colorlib-hero {
	min-height: 700px;
	background: $brand-white url(../images/loader.gif) no-repeat center center;
	width: 100%;
	float: left;
	.btn {
		font-size: 24px;
		&.btn-primary {
			padding: 14px 30px!important;
		}
	}
	.flexslider {
		border: none;
		z-index: 1;
		margin-bottom: 0;

		.slides {
			position: relative;
			overflow: hidden;
			li {
				background-repeat: no-repeat;
				background-size: cover;
				background-position: bottom center;
				min-height: 650px;
				position: relative;
				.overlay{
					position: absolute;
					top: 0;
					bottom: 0;
					left: 0;
					right: 0;
					opacity: .8;
					@include gradient-background();
				}
			}
		}
		.flex-control-nav {
			bottom: 7em;
			z-index: 1000;
			width: 0 auto;
			li {
				a {
					background: rgba(255,255,255,.2);
					box-shadow: none;
					cursor: pointer;
					&.flex-active {
						cursor: pointer;
						background: transparent;
						background: $brand-primary;
					}
				}
			}
		}

		.flex-direction-nav {
			display: none;
		}

		.slider-text{
			max-width: 100%;
			display: table;
			opacity: 0;
			height: 700px;
			z-index: 9;
			> .slider-text-inner {
				display: table-cell;
				vertical-align: middle;
				height: 700px;
				padding: 2em;
				@media screen and (max-width: $screen-sm ) {
					text-align: center;
				}
				span{
					i{
						font-size: 24px;
						color: #F7AF1D;
					}
				}
				h1, h2 {
					margin: 0;
					padding: 0;
					color: rgba($brand-white,1);
				}
				h1 {
					margin-bottom: 30px;
					font-size: 50px;
					line-height: 1.3;
					font-weight: 300;
					@media screen and (max-width: $screen-sm) {
						font-size: 28px;
					}
				}
				h2 {
					font-size: 22px;
					line-height: 1.5;
					margin-bottom: 20px;
					font-weight: 300;
					color: rgba($brand-white,.7);
					a{
						color: rgba(255,255,255,1);
					}
				}
				.heading-section{
					font-size: 50px;
					@media screen and (max-width: $screen-sm){
						font-size: 30px;
					}
				}s
				.colorlib-lead{
					font-size: 20px;
					color: $brand-primary;
					.icon-heart {
						color: $brand-danger;
					}
				}
				.btn{
					font-size: 12px;
					text-transform: uppercase;
					letter-spacing: 2px;
					color: $brand-white;
					padding: 20px 30px !important;
					border: none;
					&.btn-learn{
						background: $brand-primary;
						color: $brand-white;
					}
					&:hover{
						background: $brand-black !important;
					}
					@media screen and (max-width: $screen-xs ) {
						width: 100%;
					}
				}
			}
		}
	}

}



.colorlib-light-grey{
	background: lighten($brand-black,98%);
}

#colorlib-about,
#colorlib-services,
#colorlib-contact,
#colorlib-testimony,
#colorlib-blog,
#colorlib-project,
#colorlib-subscribe{
	padding: 7em 0;
	clear: both;
}

#colorlib-intro{
	clear: both;
	.tabulation{
		margin-top: -6.8em;
		z-index: 1;
	}
	.tab-content{
		padding: 3em 2em !important;
		background: $brand-white;
	}
	.nav-tabs{
		margin: 0 !important;
		border: none;
		@include flex();
		@include flexwrap();
		width: 100%;
		li{
			width: 25%;
			text-align: center;
			text-transform: uppercase;
			font-weight: 500;
			font-size: 14px;
			@include flex();
			@include flexwrap();
			@media screen and(max-width: $screen-sm){
				font-size: 10px;
			}
			a{
				width: 100%;
				margin: 0;
				border: none;
				padding: 2.7em 1em !important;
				background: rgba(255,255,255,.5);
				color: lighten($brand-black,30%);
				@include border-radius(0);
				i{
					font-size: 18px;
					@media screen and(max-width: $screen-sm){
						display: block;
					}
				}
			}
			&.active{
				border-bottom: 1px solid $brand-white;
				a{
					color: $brand-black;
					border: none;
					background: $brand-white;
					bottom: 0 !important;
				}
			}
		}
	}
}

//SERVICES
.services-img{
	height: 320px;
	display: block;
	@media screen and(max-width: $screen-sm){
		margin-bottom: 20px;
	}
}
.services-desc{
	padding: 0 1em;
	@media screen and(max-width: $screen-sm){
		padding: 0;
	}
	ul{
		li{
			list-style: none;
			margin-bottom: 10px;
		}
	}
}
.services{
	margin-bottom: 30px;
	position: relative;
	background: $brand-white;
	.icon{
		line-height: 64px;
		position: absolute;
		top: 20px;
		left: 0;
		right: 0;
		i{
			font-size: 40px;
			color: $brand-primary;
		}
	}
	.desc{
		padding: 90px 20px 20px 20px;
		h3{
			font-size: 16px;
			font-weight: 500;
			text-transform: uppercase;
		}
	}
}


.bg-primary-color{
	background: $brand-primary;
	p{
		color: $brand-white !important;
	}
}
//COVER BACKGROUND
.thumb-img,
.insta-img,
.staff-img, 
.blog-img,
.colorlib-about-img,
.services-img,
.project-img{
	background-size: cover;
	background-position: center center;
	background-repeat: no-repeat;
	position: relative;
}

.aside-stretch{
	background: $brand-primary;
	&:after{
		position: absolute;
		top: 0;
		right: 100%;
		bottom: 0;
		content: '';
		width: 360%;
		background: $brand-primary;
	}
	@media screen and(max-width: $screen-sm){
		background: transparent;
		&:after{
			background: transparent;
		}
	}
}

.no-gutters {
   margin-right: 0;
   margin-left: 0;
}


// PROJECT
.project-entry{
	display: block;
	background: $brand-white;
	margin-bottom: 30px;
	position: relative;
	@include transition(.2s);
	.project-img{
		width: 100%;
		height: 350px;
		display: table;
		position: relative;
		z-index: 0;
		&:after{
			position: absolute;
			top: 0;
			bottom: 0;
			left: 0;
			right: 0;
			content: '';
			background: rgba(0,0,0,.4);
			opacity: 0;
			@include transition(.9s);
			z-index: -1;
		}
		.icon{
			display: table-cell;
			vertical-align: middle;
			z-index: 1;
			opacity: 0;
			@include transition(.3s);
			i{
				color: $brand-white;
			}
		}
	}
	.desc{
		padding: 2.5em 2em;
		display: block;
		h3{
			font-size: 16px;
			font-weight: 500;
			text-transform: uppercase;
			margin-bottom: 0;
			a{
				color: $brand-black;
			}
		}
	}
	&:hover{
		top: -1px;
		-webkit-box-shadow: 0px 12px 62px -13px rgba(0,0,0,0.11);
		-moz-box-shadow: 0px 12px 62px -13px rgba(0,0,0,0.11);
		box-shadow: 0px 12px 62px -13px rgba(0,0,0,0.11);
		.project-img{
			&:after{
				opacity: 1;
			}
			.icon{
				opacity: 1;
			}
		}
	}
}

//PROJECT SINGLE
.project-single{
	margin-bottom: 30px;
}
.thumb-wrap{
	display: block;
	width: 100%;
	float: left;
	.thumb-img{
		width: 100%;
		display: block;
		height: 150px;
		margin-bottom: 30px;
	}
}
.project-single-desc{
	width: 100%;
	float: left;
	padding: 3em;
	background: $brand-white;
	margin-bottom: 1em;
	h2{
		margin-bottom: 40px;
		font-size: 24px;
		text-transform: uppercase;
		font-weight: 500;
	}
	.list{
		width: 100%;
		float: left;
		margin: 0;
		padding: 0;
		li{
			list-style: none;
			width: 100%;
			display: block;
			margin-bottom: 20px;
			.title{
				font-weight: 500;
				color: $brand-black;
				width: 50%;
				float: left;
			}
		}
	}
}
.downloadreport{
	width: 100%;
	float: left;
	font-size: 16px;
	font-weight: 500;
	a{
		width: 100%;
		float: left;
		padding: 3em 2em;
		background: $brand-white;
		&:hover{
			background: $brand-primary;
			color: $brand-white;
		}
	}
}

//TESTIMONY
#colorlib-testimony{
	background: $brand-white;
	.owl-theme .owl-controls {
	}
	.owl-theme .owl-controls .owl-nav [class*=owl-]{
		@include transition(.3s);
		@include border-radius(1px);
		background: transparent;
		// background: lighten($brand-black,95%);
		padding: 5px 5px;
		opacity: 1;
		.owl-direction{
			background: transparent;
			color: $brand-black;
			box-shadow: none;
			border: none;
			font-size: 20px;
		}
	}


	///
	.testimony-slide{
		display: block;
		position: relative;
		height: auto;
		width: 100%;
		span{
			font-size: 18px;
			font-weight: 400;
			display: block;
			color: $brand-black;
			margin-bottom: 20px;
		}

		figure{
			display: block;
			width: 100%;
			position: absolute;
			top: -70px;
			left: 0;
			right: 0;
			img {
				width: 140px;
				margin: 0 auto;
				@include border-radius(50%);
			}
		}

		blockquote{
			border: none;
			margin: 0 auto;
			width: 100%;
			position: relative;
			padding: 3em 0 0 0;
			color: $brand-black;
			p{
				font-size: 14px;
			}
		}
	}
	.testimony-wrap{
		// background: $brand-white;
		padding: 3em;
		width: 100%;
		float: left;
	}
	.owl-stage-outer{
		padding-top: 6em;
	}
}

// Counters
#colorlib-counter{
	position: relative;
}
.counter-entry{
	padding: 7em 0;
	@media screen and(max-width: $screen-sm){
		padding: 4em 0;
	}
}
.colorlib-counters {
	// padding: 3em 0;
	background-size: cover;
	background-attachment: fixed;
	background-position: center center;
	.overlay {
		z-index: 0;
		position: absolute;
		bottom: 0;
		top: 0;
		left: 0;
		right: 0;
		background: rgba($brand-black,.4);
	}
	.icon{
		width: 100px;
		height: 100px;
		display: table;
		margin: 0 auto;
		margin-bottom: 20px;
		i{
			display: table-cell;
			vertical-align: middle;
			width: 100px;
			height: 100px;
			font-size: 50px;
			color: $brand-white;
			background: $brand-primary;
			@include border-radius(50%);
		}
	}
	.icon-white{
		i{
			background: $brand-white;
			color: $brand-primary;
			@media screen and(max-width: $screen-sm){
				background: $brand-primary;
				color: $brand-white;
			}
		}
	}
	.colorlib-counter {
		font-size: 40px;
		display: block;
		color: rgba($brand-white,1);
		font-family: $font-primary;
		width: 100%;
		font-weight: 500;
		margin-bottom: .3em;
	}
	.colorlib-counter-label {
		color: rgba($brand-white,.7);
		text-transform: uppercase;
		font-size: 14px;
		letter-spacing: 5px;
		display: block;
	}
}

article{
	margin-bottom: 3em;
	.blog-img{
		width: 100%;
		display: block;
		height: 300px;
		display: table;
		position: relative;
		z-index: 0;
		&:after{
			position: absolute;
			top: 0;
			bottom: 0;
			left: 0;
			right: 0;
			content: '';
			background: rgba(0,0,0,.4);
			opacity: 0;
			@include transition(.9s);
			z-index: -1;
		}
		.icon{
			display: table-cell;
			vertical-align: middle;
			z-index: 1;
			opacity: 0;
			@include transition(.3s);
			i{
				color: $brand-white;
			}
		}
	}
	&:hover{
		.blog-img{
			&:after{
				opacity: 1;
			}
		}
		.icon{
			opacity: 1;
		}
	}
	.entry{
		width: 100%;
		margin-top: 0;
		z-index: 1;
		background: $brand-white;
		padding: 2em;
		position: relative;
		h2{
			font-weight: 500;
			font-size: 20px;
			line-height: 1.7;
			a{
				color: $brand-black;
				&:hover{
					color: $brand-primary;
				}
			}
		}
		.meta-2{
			color: lighten($brand-black,70%);
			span{
				margin-right: 10px;
				i{
					color: lighten($brand-black,40%);
				}
			}
		}
	}
}


// ABOUT
.about-wrap{
	width: 100%;
	float: left;
	padding-bottom: 0;
	@media screen and(max-width: $screen-sm){
		padding-bottom: 3em;
	}
}
#colorlib-about{
	position: relative;
	z-index: 0;
	width: 100%;
	display: block;
	.overlay{
		position: absolute;
		top: 0;
		left: 0;
		right: 0;
		bottom: 0;
		content: '';
		background: rgba(0,0,0,.5);
		z-index: -1;
	}
	.colorlib-heading2{
		h2{
			color: $brand-white;
		}
		p{
			color: rgba(255,255,255,.7);
		}
	}
}
.colorlib-about-img{
	height: 603px;
}
.about-flex{
	width: 100%;
	float: left;
	@include flex();
	@include flexwrap();
	.col-half{
		width: 50%;
		float: left;
		@media screen and(max-width: $screen-sm){
			width: 100%;
		}
		&:last-child{
			background: $brand-white;
		}
	}
	.staff-img{
		float: left;
		width: 50%;
		height: 300px;
		position: relative;
		display: table;
		@media screen and(max-width: $screen-sm){
			height: 200px;
		}
		.desc-staff{
			background: $brand-primary;
			display: table-cell;
			vertical-align: middle;
			text-align: center;
			@include transition(.3s);
			opacity: 0;
			h3{
				color: $brand-white;
			}
			span{
				color: $brand-white;
			}
		}
		&:hover{
			.desc-staff{
				opacity: 1;
			}
		}
	}
	.desc{
		padding: 4em;
		display: block;
		@media screen and(max-width: $screen-sm){
			padding: 1.5em;
		}
	}
}
//PANEL
.fancy-collapse-panel .panel-default > .panel-heading {
	padding: 0;
}
.panel-heading a {
	padding: 15px 25px;
	display: block;
	width: 100%;
	font-weight: 500;
	font-size: 14px;
	text-transform: uppercase;
	background-color: $brand-primary;
	color: $brand-white;
	position: relative;
	-webkit-box-shadow: none !important;
	-moz-box-shadow: none !important;
	-ms-box-shadow: none !important;
	-o-box-shadow: none !important;
	box-shadow: none !important;

}
.panel{
	-webkit-box-shadow: none !important;
	-moz-box-shadow: none !important;
	-ms-box-shadow: none !important;
	-o-box-shadow: none !important;
	box-shadow: none !important;
	border: none;
}
.panel-heading a:after {
	font-family: "icomoon";
	content: "\e115";
	position: absolute;
	right: 20px;
	font-size: 12px;
	font-weight: 400;
	top: 50%;
	line-height: 1;
	margin-top: -5px;
}

.panel-heading a.collapsed:after {
content: "\e114";
}
.panel-heading a.collapsed{
	background: lighten($brand-black,98%);
	border: 1px solid lighten($brand-black,90%) !important;
	color: lighten($brand-black,20%);
}
.panel-body{
	padding: 1.5em;
	margin-top: 5px;
	border: 1px solid lighten($brand-black,90%) !important;
}

//ABOUT PAGE
.about-desc{
	h3{
		font-weight: 500;
	}
}

.staff-img2{
	float: left;
	width: 100%;
	height: 300px;
	position: relative;
	display: table;
	@media screen and(max-width: $screen-sm){
		margin-bottom: 30px;
	}
	.desc-staff{
		background: $brand-primary;
		display: table-cell;
		vertical-align: middle;
		text-align: center;
		@include transition(.3s);
		opacity: 0;
		h3{
			color: $brand-white;
		}
		span{
			color: $brand-white;
		}
	}
	&:hover{
		.desc-staff{
			opacity: 1;
		}
	}
}


// CONTACT
.contact-info-wrap-flex{
	@include flex();
	@include flexwrap();
	width: 100%;
	margin-bottom: 3em;
	.con-info{
		width: 24%;
		background: $brand-white;
		padding: 1.5em;
		margin-left: 10px;
		&:first-child{
			margin-left: 0;
		}
		@media screen and(max-width: $screen-sm){
			width: 100%;
			margin: 4px !important;
		}
	}
	p{
		margin-bottom: 0;
		color: $brand-black;
		a{
			color: $brand-black;
		}
	}
}


//FORM CONTROL
.form-control {
	-webkit-box-shadow: none;
	-moz-box-shadow: none;
	-ms-box-shadow: none;
	-o-box-shadow: none;
	box-shadow: none;
	border: none;
	font-size: 16px !important;
	font-weight: 300;
	background: $brand-white;
	@include border-radius(0px);
	
	&:focus, &:active {
		box-shadow: none;
		border: 2px solid rgba(0,0,0,.8);
	}

}
input[type="text"] {
	height: 50px;
}
.form-group{
	margin-bottom: 30px;
	#fname{
		@media screen and(max-width: $screen-sm){
			margin-bottom: 30px;
		}
	}
	label{
		font-weight: 400;
	}
	.btn-modify{
		text-transform: uppercase;
		letter-spacing: 1px;
		font-weight: 700;
		font-size: 13px;
		padding: 10px 15px;
	}
}


.colorlib-social-icons {
	margin: 0;
	padding: 0;
	li {
		margin: 0;
		padding: 0;
		list-style: none;
		@include inline-block;
		a {
			@include inline-block;
			color: $brand-primary;
			padding-left: 10px;
			padding-right: 10px;
			i {
				font-size: 20px;
			}
		}
	}
}


.colorlib-heading {
	margin-bottom: 5em;
	h2{
		font-size: 30px;
		font-weight: 500;
		text-transform: uppercase;
	}
}

#colorlib-subscribe{
	background: lighten($brand-black,93%);
	padding: 5em 0;
	.colorlib-heading{
		margin-bottom: 20px;
		h2{
		}
		p{
			font-size: 18px;
		}
	}
}
.qbstp-header-subscribe {
	@include flex();
	@include flexwrap();
	width: 100%;
	padding: 0;
	.col-three-forth{
		width: 70%;
	}
	.col-one-third{
		width: 30%;
	}
	.col-three-forth, .col-one-third{
		display: table;
		height: 50px;
		float: left;
		@media screen and(max-width: $screen-sm){
			width: 50%;
		}
	}

	.form-control{
		background: transparent;
	}

	.form-group{
		position: relative;
		width: 100%;
		display: table-cell;
		vertical-align: middle;
		@media screen and (max-width: $screen-xs){
			width: 100%;
		}
		input::-webkit-input-placeholder {
			color: lighten($brand-black,20%);
		}
		input::-moz-input-placeholder {
			color: lighten($brand-black,20%);
		}
		input::-ms-input-placeholder {
			color: lighten($brand-black,20%);
		}
		input::-o-input-placeholder {
			color: lighten($brand-black,20%);
		}
		input::input-placeholder {
			color: lighten($brand-black,20%);
		}
	}
	#email {
		font-size: 14px;
		width: 100%;
		border: none;
		border-bottom: 1px solid lighten($brand-black,80%);
		color: lighten($brand-black,20%) !important;
	}
	button {
		border-top-left-radius: 0px!important;
		border-bottom-left-radius: 0px!important;
		background: $brand-primary;
		color: $brand-white;
		border: none;
		padding: 10px 20px;
		text-transform: uppercase;
		height: 50px;
		width: 100%;
		display: block;
	}
}

//INTAGRAM
.instagram{
	.insta-img{
		height: 80px;
		display: block;
		width: 33.3333%;
		float: left;
	}
}

#colorlib-footer {
	background: lighten($brand-footer-color,3%);
	color: rgba($brand-white,.6)!important;
	.contact-information{
		background: $brand-footer-color;
		padding: 1.5em 0;
		margin-bottom: 5em;
		.info-wrap{
			.icon{
				display: block;
				margin-bottom: 10px;
				i{
					color: $brand-white;
					font-size: 20px;
				}
			}
			p{
				font-size: 13px;
			}
			a{
				color: rgba(255,255,255,.5);
			}			
		}
	}
	.colorlib-widget{
		@media screen and(max-width: $screen-sm){
			margin-bottom: 40px;
			width: 100%;
			float: left;
		}
	}
	.colorlib-footer-links {
		padding: 0;
		margin: 0;
		@media screen and(max-width: $screen-sm){
			margin-bottom: 30px;
		}
		li {
			padding: 0;
			margin: 0 0 10px 0;
			list-style: none;
			display: block;
			span{
				display: block;
				font-size: 13px;
			}
			a {
				color: rgba($brand-white,.9);
				text-decoration: none;
				i{
					padding-right: 10px;
					color: $brand-primary;
				}
				&:hover {
					text-decoration: underline;
				}
			}
		}
	}
	.colorlib-social-icons {
		li {
			a {
				padding-left: 10px;
				padding-right: 10px;
				&:first-child{
					padding-left: 0;
				}
			}
		}
	}

	h4 {
		margin-bottom: 30px;
		font-size: 13px;
		color: darken($brand-white,10%);
		text-transform: uppercase;
		letter-spacing: 5px;
		font-weight: 700;
	}
	.copy{
		background: $brand-primary;
		padding: 1.2em 0;
		p{
			margin-bottom: 0;
			color: $brand-black;
			small{
				a{
					color: rgba(0,0,0,.7);
				}
			}
		}
	}
}

// Map
#map {
	width: 100%;
	height: 500px;
	position: relative;
	@media screen and (max-width: $screen-sm) {
		height: 200px;
	}
}

// off canvas
#colorlib-offcanvas {
	position: absolute;
	z-index: 1901;
	width: 270px;
	background: lighten($brand-black, 0%);
	top: 0;
	right: 0;
	top: 0;
	bottom: 0;
	padding: 75px 40px 40px 40px;
	overflow-y: auto;
	display: none;
	@include translateX(270px);
	@include transition(.5s);
	@media screen and(max-width: $screen-sm){
		display: block;
	}
	.offcanvas & {
		@include translateX(0px);
	}
	a {
		color: rgba(255,255,255,.5);
		&:hover {
			color: rgba(255,255,255,.8);
		}
	}
	ul {
		padding: 0;
		margin: 0;
		li {
			padding: 0;
			margin: 0;
			list-style: none;
			> ul {
				padding-left: 20px;
				display: none;
			}
			&.offcanvas-has-dropdown {
				> a {
					display: block;
					position: relative;
					&:after {
						position: absolute;
						right: 0px;
						@include icomoon;
						content: "\e0c5";
						font-size: 20px;
						color: rgba(255,255,255,.2);
						@include transition(.5s);
					}
				}
				&.active {
					a {
						&:after {
							-webkit-transform: rotate(-180deg);
							-moz-transform: rotate(-180deg);
							-ms-transform: rotate(-180deg);
							-o-transform: rotate(-180deg);
							transform: rotate(-180deg);
						}
					}
				}
			}
		}
	}
}

.gototop {
	position: fixed;
	bottom: 20px;
	right: 20px;
	z-index: 999;
	opacity: 0;
	visibility: hidden;
	@include transition(.5s);
	&.active {
		opacity: 1;
		visibility: visible;
	}
	a {
		width: 50px;
		height: 50px;
		display: table;
		background: rgba($brand-primary,1);
		color: $brand-white;
		text-align: center;
		@include border-radius(4px);
		i {
			height: 50px;
			display: table-cell;
			vertical-align: middle;

		}
		&:hover, &:active, &:focus {
			text-decoration: none;
			outline: none;
		}
	}	
}



// Burger Menu
.colorlib-nav-toggle {
  width:25px;
  height:25px;
  cursor: pointer;
  text-decoration: none;
  top: 1.6em !important;
  &.active i {
		&::before, &::after {
			background: $brand-darker;
		}
  }
  &:hover, &:focus, &:active {
  	outline: none;
  	border-bottom: none!important;
  }
  i {
  	position: relative;
	  display: inline-block;
	  width: 25px;
	  height: 2px;
	  color: #252525;
	  font:bold 14px/.4 Helvetica;
	  text-transform: uppercase;
	  text-indent:-55px;
	  background: #252525;
	  transition: all .2s ease-out;
		 &::before, &::after {
		  content:'';
		  width: 25px;
		  height: 2px;
		  background: #252525;
		  position: absolute;
		  left:0;
		  transition:all .2s ease-out;
	  }
  }
  &.colorlib-nav-white {
  	> i {
  		color:$brand-white;
  		background: $brand-white;
  		&::before, &::after {
  			background: $brand-white;
  		}
  	}
  }
}

.colorlib-nav-toggle i::before {
  top: -7px;
}
.colorlib-nav-toggle i::after {
  bottom: -7px;
}
.colorlib-nav-toggle:hover i::before {
  top: -10px;
}
.colorlib-nav-toggle:hover i::after {
  bottom: -10px;
}
.colorlib-nav-toggle.active i {
	background: transparent;
}
.colorlib-nav-toggle.active i::before {
  top:0;
  -webkit-transform: rotateZ(45deg);
     -moz-transform: rotateZ(45deg);
      -ms-transform: rotateZ(45deg);
       -o-transform: rotateZ(45deg);
          transform: rotateZ(45deg);
          background: $brand-white;
}
.colorlib-nav-toggle.active i::after {
  bottom:0;
  -webkit-transform: rotateZ(-45deg);
     -moz-transform: rotateZ(-45deg);
      -ms-transform: rotateZ(-45deg);
       -o-transform: rotateZ(-45deg);
          transform: rotateZ(-45deg);
          background: $brand-white;
}
.colorlib-nav-toggle {
  position: absolute;
  right: 0px;
  top: 65px;
  z-index: 21;
  padding: 6px 0 0 0;
  display: block;
  margin: 0 auto;
  display: none;
  // background: #f86942;
  height: 44px;
  width: 44px;
  z-index: 2001;
  border-bottom: none!important;
  @media screen and (max-width: $screen-sm) {
  	display: block;
  }
}

// Buttons
.btn {
	margin-right: 4px;
	margin-bottom: 4px;
	font-size: 16px;
	font-weight: 400;
	@include border-radius(0);
	@include transition(.5s);
	padding: 8px 20px;
	&.btn-md {
		padding: 8px 20px!important;
	}
	&.btn-lg {
		padding: 18px 36px!important;
	}
	&:hover, &:active, &:focus {
		box-shadow: none!important;
		outline: none!important;
	}
}
.btn-primary {
	background: $brand-primary;
	color: $brand-white;
	border: 2px solid $brand-primary;
	&:hover, &:focus, &:active {
		background: lighten($brand-primary, 5%)!important;
		border-color: lighten($brand-primary, 5%)!important;
	}
	&.btn-outline {
		background: transparent;
		color: $brand-primary;
		border: 2px solid $brand-primary;
		&:hover, &:focus, &:active {
			background: $brand-primary;
			color: $brand-white;
		}
	}
}
.btn-success {
	background: $brand-success;
	color: $brand-white;
	border: 2px solid $brand-success;
	&:hover, &:focus, &:active {
		background: darken($brand-success, 5%)!important;
		border-color: darken($brand-success, 5%)!important;
	}
	&.btn-outline {
		background: transparent;
		color: $brand-success;
		border: 2px solid $brand-success;
		&:hover, &:focus, &:active {
			background: $brand-success;
			color: $brand-white;
		}
	}
}
.btn-info {
	background: $brand-info;
	color: $brand-white;
	border: 2px solid $brand-info;
	&:hover, &:focus, &:active {
		background: darken($brand-info, 5%)!important;
		border-color: darken($brand-info, 5%)!important;
	}
	&.btn-outline {
		background: transparent;
		color: $brand-info;
		border: 2px solid $brand-info;
		&:hover, &:focus, &:active {
			background: $brand-info;
			color: $brand-white;
		}
	}
}
.btn-warning {
	background: $brand-warning;
	color: $brand-white;
	border: 2px solid $brand-warning;
	&:hover, &:focus, &:active {
		background: darken($brand-warning, 5%)!important;
		border-color: darken($brand-warning, 5%)!important;
	}
	&.btn-outline {
		background: transparent;
		color: $brand-warning;
		border: 2px solid $brand-warning;
		&:hover, &:focus, &:active {
			background: $brand-warning;
			color: $brand-white;
		}
	}
}
.btn-danger {
	background: $brand-danger;
	color: $brand-white;
	border: 2px solid $brand-danger;
	&:hover, &:focus, &:active {
		background: darken($brand-danger, 5%)!important;
		border-color: darken($brand-danger, 5%)!important;
	}
	&.btn-outline {
		background: transparent;
		color: $brand-danger;
		border: 2px solid $brand-danger;
		&:hover, &:focus, &:active {
			background: $brand-danger;
			color: $brand-white;
		}
	}
}

.btn-outline {
	background: none;
	border: 2px solid lighten($brand-black, 50%);
	font-size: 16px;
	@include transition(.3s);
	&:hover, &:focus, &:active {
		box-shadow: none;
	}
}

.btn.with-arrow {
	position: relative;
	@include transition(.3s);
	i {
		visibility: hidden;
		opacity: 0;
		position: absolute;
		right: 0px;
		top: 50%;
		margin-top: -8px;
		@include transition(.2s);
	}
	&:hover {
		padding-right: 50px;
		i {
			color: $brand-white;
			right: 18px;
			visibility: visible;
			opacity: 1;
		}
	}
}

.row-pb-lg {
	padding-bottom: 7em !important;
}
.row-pb-md {
	padding-bottom: 5em !important;
}
.row-pb-sm {
	padding-bottom: 2em !important;
}

.nopadding {
   padding: 0 !important;
   margin: 0 !important;
}

.colorlib-loader {
	position: fixed;
	left: 0px;
	top: 0px;
	width: 100%;
	height: 100%;
	z-index: 9999;
	background: url(../images/loader.gif) center no-repeat #fff;
}

.animate-box {
	.js & {
		opacity: 0;
	}
}